@@ -23,7 +23,7 @@ extern "C" {
  *
  * Library version string
  */
-#define LIBSMARTCOLS_VERSION   "2.37.1"
+#define LIBSMARTCOLS_VERSION   "2.38.0"
 
 /**
  * libscols_iter:
@@ -95,7 +95,8 @@ enum {
 	SCOLS_JSON_NUMBER    = 1,
 	SCOLS_JSON_BOOLEAN   = 2,
 	SCOLS_JSON_ARRAY_STRING = 3,        /* e.g. for multi-line (SCOLS_FL_WRAP) cells */
-	SCOLS_JSON_ARRAY_NUMBER	= 4
+	SCOLS_JSON_ARRAY_NUMBER	= 4,
+	SCOLS_JSON_BOOLEAN_OPTIONAL = 5,
 };
 
 /*
@@ -189,6 +190,10 @@ extern int scols_column_set_color(struct libscols_column *cl, const char *color)
 extern const char *scols_column_get_color(const struct libscols_column *cl);
 extern struct libscols_table *scols_column_get_table(const struct libscols_column *cl);
 
+extern int scols_column_set_name(struct libscols_column *cl, const char *name);
+extern const char *scols_column_get_name(struct libscols_column *cl);
+extern const char *scols_column_get_name_as_shellvar(struct libscols_column *cl);
+
 extern int scols_column_set_cmpfunc(struct libscols_column *cl,
 			int (*cmp)(struct libscols_cell *a,
 				   struct libscols_cell *b, void *),
@@ -229,6 +234,7 @@ extern struct libscols_cell *scols_line_get_column_cell(
 extern int scols_line_set_data(struct libscols_line *ln, size_t n, const char *data);
 extern int scols_line_refer_data(struct libscols_line *ln, size_t n, char *data);
 extern int scols_line_set_column_data(struct libscols_line *ln, struct libscols_column *cl, const char *data);
+extern const char *scols_line_get_column_data(struct libscols_line *ln, struct libscols_column *cl);
 extern int scols_line_refer_column_data(struct libscols_line *ln, struct libscols_column *cl, char *data);
 extern struct libscols_line *scols_copy_line(const struct libscols_line *ln);
 
@@ -244,6 +250,7 @@ extern int scols_table_is_noheadings(const struct libscols_table *tb);
 extern int scols_table_is_header_repeat(const struct libscols_table *tb);
 extern int scols_table_is_empty(const struct libscols_table *tb);
 extern int scols_table_is_export(const struct libscols_table *tb);
+extern int scols_table_is_shellvar(const struct libscols_table *tb);
 extern int scols_table_is_maxout(const struct libscols_table *tb);
 extern int scols_table_is_minout(const struct libscols_table *tb);
 extern int scols_table_is_nowrap(const struct libscols_table *tb);
@@ -258,6 +265,7 @@ extern int scols_table_enable_json(struct libscols_table *tb, int enable);
 extern int scols_table_enable_noheadings(struct libscols_table *tb, int enable);
 extern int scols_table_enable_header_repeat(struct libscols_table *tb, int enable);
 extern int scols_table_enable_export(struct libscols_table *tb, int enable);
+extern int scols_table_enable_shellvar(struct libscols_table *tb, int enable);
 extern int scols_table_enable_maxout(struct libscols_table *tb, int enable);
 extern int scols_table_enable_minout(struct libscols_table *tb, int enable);
 extern int scols_table_enable_nowrap(struct libscols_table *tb, int enable);
